@@ -102,32 +102,32 @@
 <context>
     <name>DialogRecordDataExt</name>
     <message>
-        <location filename="DialogRecordDataExt.py" line="87"/>
+        <location filename="DialogRecordDataExt.py" line="89"/>
         <source>Attention! Data recording will continue to until it is stopped manually, or network interface will be deactivated.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="91"/>
+        <location filename="DialogRecordDataExt.py" line="93"/>
         <source>Data record is disabled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="106"/>
+        <location filename="DialogRecordDataExt.py" line="110"/>
         <source>MAC address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="107"/>
+        <location filename="DialogRecordDataExt.py" line="111"/>
         <source>RX bytes/RX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="108"/>
+        <location filename="DialogRecordDataExt.py" line="112"/>
         <source>TX bytes/TX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="109"/>
+        <location filename="DialogRecordDataExt.py" line="113"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -197,88 +197,118 @@ record</source>
 <context>
     <name>ListSessions</name>
     <message>
-        <location filename="ListSessions.py" line="84"/>
+        <location filename="ListSessions.py" line="87"/>
         <source>QNetMan (Networking sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="85"/>
+        <location filename="ListSessions.py" line="88"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="86"/>
+        <location filename="ListSessions.py" line="89"/>
         <source>Filter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="87"/>
+        <location filename="ListSessions.py" line="90"/>
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="88"/>
+        <location filename="ListSessions.py" line="91"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="89"/>
+        <location filename="ListSessions.py" line="92"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="90"/>
+        <location filename="ListSessions.py" line="93"/>
         <source>Database statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="91"/>
+        <location filename="ListSessions.py" line="94"/>
         <source>Clean database</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ListSessions.py" line="95"/>
+        <source>Calculate traffic</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListSessionsExt</name>
     <message>
-        <location filename="ListSessionsExt.py" line="95"/>
+        <location filename="ListSessionsExt.py" line="98"/>
         <source>Deleting sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="96"/>
+        <location filename="ListSessionsExt.py" line="99"/>
         <source>Delete selected sessions ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="158"/>
+        <location filename="ListSessionsExt.py" line="161"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="236"/>
+        <location filename="ListSessionsExt.py" line="240"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="237"/>
+        <location filename="ListSessionsExt.py" line="241"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="283"/>
+        <location filename="ListSessionsExt.py" line="287"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="114"/>
+        <location filename="ListSessionsExt.py" line="117"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="115"/>
+        <location filename="ListSessionsExt.py" line="118"/>
         <source>Sorry, an error in the database.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="325"/>
+        <source>Select a session to calculate the traffic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="330"/>
+        <source>Sessions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="333"/>
+        <source>Full traffic:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="331"/>
+        <source>RX bytes:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ListSessionsExt.py" line="332"/>
+        <source>TX bytes:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -585,11 +615,6 @@ connections</source>
         <source>Version:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="WinAbout.py" line="89"/>
-        <source>0.1.0 (beta)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="WinAbout.py" line="90"/>
         <source>Author:</source>
@@ -659,6 +684,11 @@ p, li { white-space: pre-wrap; }
         <source>QNetMan (Settings)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinAbout.py" line="89"/>
+        <source>0.3.0</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowExt</name>
@@ -702,80 +732,85 @@ Start daemons now ?</source>
 <context>
     <name>OptionsWindowExt</name>
     <message>
-        <location filename="OptionsWindowExt.py" line="257"/>
+        <location filename="OptionsWindowExt.py" line="296"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindowExt.py" line="258"/>
+        <location filename="OptionsWindowExt.py" line="281"/>
         <source>Should be left on at least one network interface</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="OptionsWindowExt.py" line="297"/>
+        <source>Before you disable the network interface, turn off the record on this network interface</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewCurrentSession</name>
     <message>
-        <location filename="ViewCurrentSession.py" line="172"/>
+        <location filename="ViewCurrentSession.py" line="182"/>
         <source>QNetMan (Monitor)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="185"/>
+        <location filename="ViewCurrentSession.py" line="195"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="175"/>
+        <location filename="ViewCurrentSession.py" line="185"/>
         <source>000.00 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="186"/>
+        <location filename="ViewCurrentSession.py" line="196"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="178"/>
+        <location filename="ViewCurrentSession.py" line="188"/>
         <source>V</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="180"/>
+        <location filename="ViewCurrentSession.py" line="190"/>
         <source>000.00 MB/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="181"/>
+        <location filename="ViewCurrentSession.py" line="191"/>
         <source>rx</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="182"/>
+        <location filename="ViewCurrentSession.py" line="192"/>
         <source>tx</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="183"/>
+        <location filename="ViewCurrentSession.py" line="193"/>
         <source>Interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="184"/>
+        <location filename="ViewCurrentSession.py" line="194"/>
         <source>2 sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="187"/>
+        <location filename="ViewCurrentSession.py" line="197"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="188"/>
+        <location filename="ViewCurrentSession.py" line="198"/>
         <source>Refresh interval</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="189"/>
+        <location filename="ViewCurrentSession.py" line="199"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -783,20 +818,25 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSessionExt</name>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="332"/>
+        <location filename="ViewCurrentSessionExt.py" line="357"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="333"/>
+        <location filename="ViewCurrentSessionExt.py" line="358"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="394"/>
+        <location filename="ViewCurrentSessionExt.py" line="423"/>
         <source>Selected network interface:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ViewCurrentSessionExt.py" line="466"/>
+        <source>Recording...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewSessionExt</name>
