@@ -24,13 +24,13 @@ class OptionsWindowExt( QtGui.QMainWindow ):
 		self.ui = OptionsWindow.Ui_MainWindow()
 		self.ui.setupUi( self )
 
-		#TODO: УСТАРЕЛО: заменить на получение из БД списка интерфейсов
 		self.bufSupportedIface = {}
-		self.bufSupportedIface[1] = "gprs0"
-		self.bufSupportedIface[2] = "wlan0"
-		self.bufSupportedIface[3] = "usb0"
-		self.bufSupportedIface[4] = "pan0"
-		self.bufSupportedIface[5] = "eth0"
+		self.bufSupportedIface = self.db.getBuffIface()
+		#self.bufSupportedIface[1] = "gprs0"
+		#self.bufSupportedIface[2] = "wlan0"
+		#self.bufSupportedIface[3] = "usb0"
+		#self.bufSupportedIface[4] = "pan0"
+		#self.bufSupportedIface[5] = "eth0"
 		self.fl_gprs = False
 		self.fl_wlan = False
 		self.fl_usb = False
